@@ -164,7 +164,7 @@ def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_d
     return rsp.rsp_result.result == "success"
 
 
-CHUNK_SIZE = 4* 1024 * 1024  # 1MB
+CHUNK_SIZE = 4* 1024 * 1024  # 4MB
 
 
 def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_id: int, artifact_id: int,
@@ -378,7 +378,10 @@ def login(key: str) -> (bool, str):
 
             #creds = grpc.ssl_channel_credentials()
             grpc_channel_args = ()
-            grpc_channel_args += (('grpc.max_receive_message_length', 100*1024*1024),)
+            grpc_channel_args += (
+                ('grpc.max_receive_message_length', 10*1024*1024),
+                ('grpc.max_receive_message_length', 10*1024*1024),
+            )
             channel = grpc.secure_channel(target =grpc_url, credentials=creds, options=grpc_channel_args)
         else:
             channel = grpc.insecure_channel(grpc_url)
